/*-
 * Copyright (c) 2011 Juergen Lock
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer 
 *    in this position and unchanged.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. The name of the author may not be used to endorse or promote products
 *    derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
 * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 * $FreeBSD$
 */

#ifndef _LINUX_V4L2_IOCTL_H_
#define	_LINUX_V4L2_IOCTL_H_

/*
 * ioctl
 *
 * XXX comments in Linux' <asm-generic/ioctl.h> indicate these
 * could be arch-dependant...
 */
#define LINUX_IOC_VOID		0
#define LINUX_IOC_IN		0x40000000
#define LINUX_IOC_OUT		0x80000000
#define LINUX_IOC_INOUT		(LINUX_IOC_IN|LINUX_IOC_OUT)

/* videodev2 aka V4L2 */

#define LINUX_VIDIOC_QUERYCAP			0x5600 /* 0x80685600 */
#define LINUX_VIDIOC_RESERVED			0x5601 /* 0x00005601 */
#define LINUX_VIDIOC_ENUM_FMT			0x5602 /* 0xc0405602 */
#define LINUX_VIDIOC_G_FMT			0x5604 /* 0xc0cc5604 */
#define LINUX_VIDIOC_S_FMT			0x5605 /* 0xc0cc5605 */
#define LINUX_VIDIOC_REQBUFS			0x5608 /* 0xc0145608 */
#define LINUX_VIDIOC_QUERYBUF			0x5609 /* 0xc0445609 */
#define LINUX_VIDIOC_G_FBUF			0x560a /* 0x802c560a */
#define LINUX_VIDIOC_S_FBUF			0x560b /* 0x402c560b */
#define LINUX_VIDIOC_OVERLAY			0x560e /* 0x4004560e */
#define LINUX_VIDIOC_QBUF			0x560f /* 0xc044560f */
#define LINUX_VIDIOC_DQBUF			0x5611 /* 0xc0445611 */
#define LINUX_VIDIOC_STREAMON			0x5612 /* 0x40045612 */
#define LINUX_VIDIOC_STREAMOFF			0x5613 /* 0x40045613 */
#define LINUX_VIDIOC_G_PARM			0x5615 /* 0xc0cc5615 */
#define LINUX_VIDIOC_S_PARM			0x5616 /* 0xc0cc5616 */
#define LINUX_VIDIOC_G_STD			0x5617 /* 0x80085617 */
#define LINUX_VIDIOC_S_STD			0x5618 /* 0x40085618 */
#define LINUX_VIDIOC_ENUMSTD			0x5619 /* 0xc0405619 */
#define LINUX_VIDIOC_ENUMINPUT			0x561a /* 0xc04c561a */
#define LINUX_VIDIOC_G_CTRL			0x561b /* 0xc008561b */
#define LINUX_VIDIOC_S_CTRL			0x561c /* 0xc008561c */
#define LINUX_VIDIOC_G_TUNER			0x561d /* 0xc054561d */
#define LINUX_VIDIOC_S_TUNER			0x561e /* 0x4054561e */
#define LINUX_VIDIOC_G_AUDIO			0x5621 /* 0x80345621 */
#define LINUX_VIDIOC_S_AUDIO			0x5622 /* 0x40345622 */
#define LINUX_VIDIOC_QUERYCTRL			0x5624 /* 0xc0445624 */
#define LINUX_VIDIOC_QUERYMENU			0x5625 /* 0xc02c5625 */
#define LINUX_VIDIOC_G_INPUT			0x5626 /* 0x80045626 */
#define LINUX_VIDIOC_S_INPUT			0x5627 /* 0xc0045627 */
#define LINUX_VIDIOC_G_OUTPUT			0x562e /* 0x8004562e */
#define LINUX_VIDIOC_S_OUTPUT			0x562f /* 0xc004562f */
#define LINUX_VIDIOC_ENUMOUTPUT			0x5630 /* 0xc0485630 */
#define LINUX_VIDIOC_G_AUDOUT			0x5631 /* 0x80345631 */
#define LINUX_VIDIOC_S_AUDOUT			0x5632 /* 0x40345632 */
#define LINUX_VIDIOC_G_MODULATOR		0x5636 /* 0xc0445636 */
#define LINUX_VIDIOC_S_MODULATOR		0x5637 /* 0x40445637 */
#define LINUX_VIDIOC_G_FREQUENCY		0x5638 /* 0xc02c5638 */
#define LINUX_VIDIOC_S_FREQUENCY		0x5639 /* 0x402c5639 */
#define LINUX_VIDIOC_CROPCAP			0x563a /* 0xc02c563a */
#define LINUX_VIDIOC_G_CROP			0x563b /* 0xc014563b */
#define LINUX_VIDIOC_S_CROP			0x563c /* 0x4014563c */
#define LINUX_VIDIOC_G_JPEGCOMP			0x563d /* 0x808c563d */
#define LINUX_VIDIOC_S_JPEGCOMP			0x563e /* 0x408c563e */
#define LINUX_VIDIOC_QUERYSTD			0x563f /* 0x8008563f */
#define LINUX_VIDIOC_TRY_FMT			0x5640 /* 0xc0cc5640 */
#define LINUX_VIDIOC_ENUMAUDIO			0x5641 /* 0xc0345641 */
#define LINUX_VIDIOC_ENUMAUDOUT			0x5642 /* 0xc0345642 */
#define LINUX_VIDIOC_G_PRIORITY			0x5643 /* 0x80045643 */
#define LINUX_VIDIOC_S_PRIORITY			0x5644 /* 0x40045644 */
#define LINUX_VIDIOC_G_SLICED_VBI_CAP		0x5645 /* 0xc0745645 */
#define LINUX_VIDIOC_LOG_STATUS			0x5646 /* 0x00005646 */
#define LINUX_VIDIOC_G_EXT_CTRLS		0x5647 /* 0xc0185647 */
#define LINUX_VIDIOC_S_EXT_CTRLS		0x5648 /* 0xc0185648 */
#define LINUX_VIDIOC_TRY_EXT_CTRLS		0x5649 /* 0xc0185649 */
#define LINUX_VIDIOC_ENUM_FRAMESIZES		0x564a /* 0xc02c564a */
#define LINUX_VIDIOC_ENUM_FRAMEINTERVALS	0x564b /* 0xc034564b */
#define LINUX_VIDIOC_G_ENC_INDEX		0x564c /* 0x8818564c */
#define LINUX_VIDIOC_ENCODER_CMD		0x564d /* 0xc028564d */
#define LINUX_VIDIOC_TRY_ENCODER_CMD		0x564e /* 0xc028564e */
#define LINUX_VIDIOC_DBG_S_REGISTER		0x564f /* 0x4038564f */
#define LINUX_VIDIOC_DBG_G_REGISTER		0x5650 /* 0xc0385650 */
#define LINUX_VIDIOC_DBG_G_CHIP_IDENT		0x5651 /* 0xc02c5651 */
#define LINUX_VIDIOC_S_HW_FREQ_SEEK		0x5652 /* 0x40305652 */
#define LINUX_VIDIOC_ENUM_DV_PRESETS		0x5653 /* 0xc0405653 */
#define LINUX_VIDIOC_S_DV_PRESET		0x5654 /* 0xc0145654 */
#define LINUX_VIDIOC_G_DV_PRESET		0x5655 /* 0xc0145655 */
#define LINUX_VIDIOC_QUERY_DV_PRESET		0x5656 /* 0x80145656 */
#define LINUX_VIDIOC_S_DV_TIMINGS		0x5657 /* 0xc0845657 */
#define LINUX_VIDIOC_G_DV_TIMINGS		0x5658 /* 0xc0845658 */
#define LINUX_VIDIOC_DQEVENT			0x5659 /* 0x80785659 */
#define LINUX_VIDIOC_SUBSCRIBE_EVENT		0x565a /* 0x4020565a */
#define LINUX_VIDIOC_UNSUBSCRIBE_EVENT		0x565b /* 0x4020565b */

#define LINUX_VIDIOC_OVERLAY_OLD		0x560e /* 0xc004560e */
#define LINUX_VIDIOC_S_PARM_OLD			0x5616 /* 0x40cc5616 */
#define LINUX_VIDIOC_S_CTRL_OLD			0x561c /* 0x4008561c */
#define LINUX_VIDIOC_G_AUDIO_OLD		0x5621 /* 0xc0345621 */
#define LINUX_VIDIOC_G_AUDOUT_OLD		0x5631 /* 0xc0345631 */
#define LINUX_VIDIOC_CROPCAP_OLD		0x563a /* 0x802c563a */

#define LINUX_IOCTL_VIDEO2_MIN	LINUX_VIDIOC_QUERYCAP
#define LINUX_IOCTL_VIDEO2_MAX	LINUX_VIDIOC_UNSUBSCRIBE_EVENT

#endif /* !_LINUX_V4L2_IOCTL_H_ */
